@@ -6,6 +6,17 @@ extern "C"
 {
 #endif
 
+/// Represents an endianness of a CPU.
+typedef enum
+{
+    /// An unknown-endian.
+    NSTD_CPU_ENDIAN_UNKNOWN,
+    /// Little-endian.
+    NSTD_CPU_ENDIAN_LITTLE,
+    /// Big-endian.
+    NSTD_CPU_ENDIAN_BIG,
+} NSTDCPUEndian;
+
 /// Represents a CPU architecture.
 typedef enum
 {
@@ -96,6 +107,27 @@ typedef enum
     NSTD_OPERATING_SYSTEM_VXWORKS
 } NSTDOperatingSystem;
 
+/// Represents a computing platform.
+typedef struct
+{
+    /// The size (in bytes) of a pointer.
+    NSTDUSize ptr_size;
+    /// The CPU endianness.
+    NSTDCPUEndian endian;
+    /// The CPU architecture.
+    NSTDCPUArch arch;
+    /// The operating system.
+    NSTDOperatingSystem os;
+} NSTDPlatform;
+
+/// Returns the size (in bytes) of a pointer.
+/// Returns: `NSTDUSize size` - Size of a pointer.
+NSTDAPI NSTDUSize nstd_core_platform_ptr_size();
+
+/// Returns the target CPU's endianness.
+/// Returns: `NSTDCPUEndian endian` - The target CPU endianness.
+NSTDAPI NSTDCPUEndian nstd_core_platform_endian();
+
 /// Returns an `NSTDCPUArch` value representing the target CPU architecture.
 /// Returns: `NSTDCPUArch arch` - The target CPU architecture.
 NSTDAPI NSTDCPUArch nstd_core_platform_arch();
@@ -104,6 +136,10 @@ NSTDAPI NSTDCPUArch nstd_core_platform_arch();
 /// Returns: `NSTDOperatingSystem os` - The target OS.
 NSTDAPI NSTDOperatingSystem nstd_core_platform_os();
 
+/// Returns an `NSTDPlatform` value representing the target platform.
+/// Returns: `NSTDPlatform platform` - The target platform.
+NSTDAPI NSTDPlatform nstd_core_platform_target();
+
 #ifdef __cplusplus
 }
 #endif
